@@ -7,7 +7,7 @@ from notion2md.console.formatter import *
 from notion2md.config import Config
 from notion2md.exceptions import UnInitializedConfigException
 
-from clikit.api.io import IO
+from cleo.io.io import IO
 
 # Since external file block cannot guarantees
 # whether the file is downloadable or not,
@@ -29,20 +29,15 @@ def downloader(url:str,io:IO=None) -> str:
             fullpath = os.path.join(cfg.tmp_path,downloaded_file_name)
             
             if io:
-                print_output(io,request.urlretrieve(url,fullpath),file_name,downloaded_file_name)
+                io.write_line(status("Downloading",f"{file_name}"))
+                request.urlretrieve(url,fullpath)
+                io.write_line(status("Downloaded",f'successfully downloaded "{file_name}" -> "{downloaded_file_name}"'))
             else:
                 request.urlretrieve(url,fullpath)
             return name,downloaded_file_name
         else:
             if io:
-                io.write_line(error(f"unvalid {url}"))
+                io.write_line(error(f"invalid {url}"))
     else:
         return file_name,url
-
-def print_output(io:IO,fn,file_name,downloaded_file_name):
-    try:
-        io.write_line(status("Downloading",f"{file_name}"))
-        fn()
-        io.write_line(status("Downloaded",f'successfully downloaded "{file_name}" -> "{downloaded_file_name}"'))
-    except Exception as e:
-        io.write_line(error(f"cannot download {file_name}"))
+        
